% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vis_grid_gene.R
\name{vis_grid_gene}
\alias{vis_grid_gene}
\title{Sample spatial gene visualization grid}
\usage{
vis_grid_gene(
  spe,
  geneid = "SCGB2A2; ENSG00000110484",
  pdf_file,
  assayname = "logcounts",
  minCount = 0,
  return_plots = FALSE,
  spatial = TRUE,
  viridis = TRUE,
  height = 24,
  width = 36,
  ...
)
}
\arguments{
\item{spe}{Defaults to the output of
\code{fetch_data(type = 'spe')}. This is a
\link[SpatialExperiment:SpatialExperiment]{SpatialExperiment-class}
object with the spot-level Visium data and information required for
visualizing the histology. See \code{\link[=fetch_data]{fetch_data()}} for more details.}

\item{geneid}{A \code{character(1)} specifying the gene ID stored in
\code{rowData(spe)$gene_search} or a continuous variable stored in \code{colData(spe)}
to visualize.}

\item{pdf_file}{A \code{character(1)} specifying the path for the resulting PDF.}

\item{assayname}{The name of the \code{assays(spe)} to use for extracting the
gene expression data. Defaults to \code{logcounts}.}

\item{minCount}{A \code{numeric(1)} specifying the minimum gene expression (or
value in the continuous variable) to visualize. Values at or below this
threshold will be set to \code{NA}. Defaults to \code{0}.}

\item{return_plots}{A \code{logical(1)} indicating whether to print the plots
to a PDF or to return the list of plots that you can then print using
\link[cowplot:plot_grid]{plot_grid}.}

\item{spatial}{A \code{logical(1)} indicating whether to include the histology
layer from \code{\link[=geom_spatial]{geom_spatial()}}. If you plan to use
\link[plotly:ggplotly]{ggplotly()} then it's best to set this to \code{FALSE}.}

\item{viridis}{A \code{logical(1)} whether to use the color-blind friendly
palette from \link[viridisLite:viridis]{viridis} or the color palette used
in the paper that was chosen for contrast when visualizing the data on
top of the histology image. One issue is being able to differentiate low
values from NA ones due to the purple-ish histology information that is
dependent on cell density.}

\item{height}{A \code{numeric(1)} passed to \link[grDevices:pdf]{pdf}.}

\item{width}{A \code{numeric(1)} passed to \link[grDevices:pdf]{pdf}.}

\item{...}{Passed to \link[base:paste]{paste0()} for making the title of the
plot following the \code{sampleid}.}
}
\value{
A list of \link[ggplot2:ggplot]{ggplot2} objects.
}
\description{
This function visualizes the gene expression stored in \code{assays(spe)} or any
continuous variable stored in \code{colData(spe)} for a set of samples at the
spot-level using (by default) the histology information on the background.
To visualize clusters (or any discrete variable) use \code{\link[=vis_grid_clus]{vis_grid_clus()}}.
}
\details{
This function prepares the data and then loops through
\code{\link[=vis_gene]{vis_gene()}} for computing the list of \link[ggplot2:ggplot]{ggplot2}
objects.
}
\examples{

if (enough_ram()) {
    ## Obtain the necessary data
    if (!exists("spe")) spe <- fetch_data("spe")

    ## Subset to two samples of interest
    spe_sub <- spe[, spe$sample_id \%in\% c("151673", "151674")]

    ## Obtain the plot list
    p_list <-
        vis_grid_gene(
            spe_sub,
            spatial = FALSE,
            return_plots = TRUE
        )

    ## Clean up
    rm(spe_sub)

    ## Visualize the spatial adjacent replicates for position = 0 micro meters
    ## for subject 3
    cowplot::plot_grid(plotlist = p_list, ncol = 2)
}
}
\seealso{
Other Spatial gene visualization functions: 
\code{\link{vis_gene_p}()},
\code{\link{vis_gene}()}
}
\concept{Spatial gene visualization functions}
